@@ -151,3 +151,9 @@ ACT_FUNC_PRELU = 'prelu'                                    # Parametric rectifi
 READOUT_MEAN = 'mean'                                       # Mean-based readout
 READOUT_SUM = 'sum'                                         # Sum-based readout
 READOUT_ATTN = 'attn'                                       # Attention-based readout
+
+
+# Hyper-parameter optimization methods
+HPARAM_OPT_GRID = 'grid'                                    # Grid search
+HPARAM_OPT_BAYES = 'bayes'                                  # Bayesian optimization
+HPARAM_OPT_GA = 'ga'                                        # Genetic algorithm
