@@ -140,7 +140,7 @@ class SKLearnModel(Model):
             self.__model = KNeighborsRegressor(n_neighbors=n_neighbors)
         elif self.alg_id == ALG_GPR:
             kernel = DotProduct() + WhiteKernel()
-            self.__model = GaussianProcessRegressor(kernel=kernel)
+            self.__model = GaussianProcessRegressor(kernel=kernel, alpha=1e-8)
         elif self.alg_id == ALG_SVR:
             c = kwargs['c'] if 'c' in kwargs.keys() else 1.0
             epsilon = kwargs['epsilon'] if 'epsilon' in kwargs.keys() else 0.1
